package	jp.co.sds_corp.report.source;

import jp.co.sds_corp.util.common.CmnProperty;
import jp.co.sds_corp.util.config.IConfiguration;

/**
* データを取得するクラスの定義です。
*/
public abstract class AbstractSource implements ISource
{
	CmnProperty	prop;
	GenericBean	bean;	// データ格納bean
	boolean	debug;	// デバッグフラグ

	/**
	* 設定情報で初期化します。
	* @param    config  設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		String flg = config.getAttributes().get( "debug", "" );
		if ( flg.equals( "true" )) {
			debug = true;
		}
		bean = new GenericBean();
	}

	/**
	* 初期情報の変換に使用するリソースを設定します。
	* @param	prop	リソース
	*/
	public void setProperty( CmnProperty prop ) {
		this.prop = prop;
	}
	/**
	* 初期情報の変換に使用するリソースを返します。
	* @return	リソース
	*/
	public CmnProperty getProperty() {
		return prop;
	}

	/**
	* データ格納beanを設定します。
	* @param	var		設定するデータ
	*/
	public void setBean( GenericBean var ) {
		this.bean = var;
	}
	/**
	* データ格納beanを取得します。
	* @return	データ格納bean
	*/
	public GenericBean getBean() {
		return bean;
	}

	/**
	* デバッグフラグを設定します。
	* @param	var		設定するデータ
	*/
	public void setDebug( boolean var ) {
		this.debug = var;
	}
	/**
	* デバッグフラグを取得します。
	* @return	デバッグフラグ
	*/
	public boolean isDebug() {
		return debug;
	}


}
